# 102218023_TEXTCONVERTOR

This package provides a simple tool to convert the contents of a file to uppercase.

## Installation

You can install the package via pip:


pip install 102218023_TEXTCONVERTOR


## Runinng

After installing the package, you can use the topisi command to convert a file's contents to uppercase. The command takes two arguments: the input file and the output file.

topisi input_file.txt output_file.txt
